@@ -132,7 +132,7 @@ AverageStatisticEpistemicTest <- function(sample1,sample2,bootstrapMethod="std",
   if(!isFuzzyData(sample1))
   {
 
-    stop("Parameter sample1 should consist of fuzzy numbers (single value or list)")
+    stop("Parameter sample1 should consist of fuzzy numbers - single value or list")
 
   }
 
@@ -140,14 +140,19 @@ AverageStatisticEpistemicTest <- function(sample1,sample2,bootstrapMethod="std",
   if(!(isFuzzyData(sample2) || is.null(sample2)))
   {
 
-    stop("Parameter sample1 should consist of fuzzy numbers (single value or list)")
+    stop("Parameter sample2 should consist of fuzzy numbers - single value or list")
 
   }
 
+  if(length(bootstrapMethod) > 1)
+  {
+    stop("Parameter bootstrapMethod should be a single value")
+  }
+
 
   if(!(bootstrapMethod %in% c("std","anti")))
   {
-    stop("Parameter bootstrapMethod should be a proper name of epistemic bootstrap method (std or anti)")
+    stop("Parameter bootstrapMethod should be a proper name of epistemic bootstrap method - std or anti")
   }
 
 
